summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2021-06-02 14:56:07 +0200
committerDaniel Stenberg <daniel@haxx.se>2021-06-02 23:03:55 +0200
commit6793332eba010770c25bcc7019d4d593b035fbe6 (patch)
treeafd146a75a9cd2744f58467fbfbaebd59d2ffc82 /include
parent9dc0baf5c611d46ff5136f1e32ef898b438e0aea (diff)
downloadcurl-6793332eba010770c25bcc7019d4d593b035fbe6.tar.gz
CURLE_SETOPT_OPTION_SYNTAX: new error name for wrong setopt syntax
For options that pass in lists or strings that are subsequently parsed and must be correct. This broadens the scope for the option previously known as CURLE_TELNET_OPTION_SYNTAX but the old name is of course still provided as a #define for existing applications. Closes #7175
Diffstat (limited to 'include')
-rw-r--r--include/curl/curl.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/include/curl/curl.h b/include/curl/curl.h
index 97de8c88a..c74874c14 100644
--- a/include/curl/curl.h
+++ b/include/curl/curl.h
@@ -541,7 +541,7 @@ typedef enum {
CURLE_OBSOLETE46, /* 46 - NOT USED */
CURLE_TOO_MANY_REDIRECTS, /* 47 - catch endless re-direct loops */
CURLE_UNKNOWN_OPTION, /* 48 - User specified an unknown option */
- CURLE_TELNET_OPTION_SYNTAX, /* 49 - Malformed telnet option */
+ CURLE_SETOPT_OPTION_SYNTAX, /* 49 - Malformed setopt option */
CURLE_OBSOLETE50, /* 50 - NOT USED */
CURLE_OBSOLETE51, /* 51 - NOT USED */
CURLE_GOT_NOTHING, /* 52 - when this is a specific error */
@@ -636,6 +636,9 @@ typedef enum {
/* The following were added in 7.21.5, April 2011 */
#define CURLE_UNKNOWN_TELNET_OPTION CURLE_UNKNOWN_OPTION
+/* Added for 7.78.0 */
+#define CURLE_TELNET_OPTION_SYNTAX CURLE_SETOPT_OPTION_SYNTAX
+
/* The following were added in 7.17.1 */
/* These are scheduled to disappear by 2009 */
#define CURLE_SSL_PEER_CERTIFICATE CURLE_PEER_FAILED_VERIFICATION